@@ -318,7 +318,7 @@ def month_datelist(start_day):
     return month_list
 
 
-def getdate(beforeOfDay: int):
+def getdate(beforeOfDay: int, fm: str = "%Y-%m-%d"):
     """
     获取前1天或N天的日期，beforeOfDay=1：前1天；beforeOfDay=N：前N天
     :param beforeOfDay:
@@ -328,7 +328,7 @@ def getdate(beforeOfDay: int):
     # 计算偏移量
     offset = datetime.timedelta(days=-beforeOfDay)
     # 获取想要的日期的时间
-    re_date = (today + offset).strftime('%Y-%m-%d')
+    re_date = (today + offset).strftime(fm)
     return re_date
 
 
